This crate contains kube-rs compatible bindings for Kubernetes custom resources for the monitoring.giantswarm.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
monitoring.giantswarm.io/v1alpha1
Silence